==> jc-1.4.0.tar.gz: javax/security/auth/login/Configuration.h <==
// public abstract class javax.security.auth.login.Configuration

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2ef6b4ae807df814 javax_security_auth_login_Configuration

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_security_auth_login_Configuration_H_
#define _JC_javax_security_auth_login_Configuration_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_security_auth_login_Configuration$object;

// Typedefs
typedef struct _jc_javax_security_auth_login_Configuration$sub_refs	_jc_javax_security_auth_login_Configuration$sub_refs;
typedef struct _jc_javax_security_auth_login_Configuration$sub_nonrefs	_jc_javax_security_auth_login_Configuration$sub_nonrefs;
typedef struct _jc_javax_security_auth_login_Configuration$refs	_jc_javax_security_auth_login_Configuration$refs;
typedef struct _jc_javax_security_auth_login_Configuration$nonrefs	_jc_javax_security_auth_login_Configuration$nonrefs;
typedef struct _jc_javax_security_auth_login_Configuration$object	_jc_javax_security_auth_login_Configuration$object;

typedef struct _jc_javax_security_auth_login_Configuration$fields_struct	_jc_javax_security_auth_login_Configuration$fields_struct;
typedef const struct _jc_javax_security_auth_login_Configuration$vmethods	_jc_javax_security_auth_login_Configuration$vmethods;
typedef const struct _jc_javax_security_auth_login_Configuration$vtable	_jc_javax_security_auth_login_Configuration$vtable;
typedef const struct _jc_javax_security_auth_login_Configuration$vtype	_jc_javax_security_auth_login_Configuration$vtype;

// Class fields structure
struct _jc_javax_security_auth_login_Configuration$fields_struct {
	struct _jc_javax_security_auth_login_Configuration$object	*config;
};
extern _jc_javax_security_auth_login_Configuration$fields_struct _jc_javax_security_auth_login_Configuration$class_fields;

// Constructors
extern void _jc_javax_security_auth_login_Configuration$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_security_auth_login_Configuration$object *);

// Virtual methods
extern _jc_object_array *_jc_javax_security_auth_login_Configuration$method$getAppConfigurationEntry$fcb698d120847e70(_jc_env *, struct _jc_javax_security_auth_login_Configuration$object *, struct _jc_java_lang_String$object *);
extern void _jc_javax_security_auth_login_Configuration$method$refresh$23f3d9d8f6b36945(_jc_env *, struct _jc_javax_security_auth_login_Configuration$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_security_auth_login_Configuration$method_info$getAppConfigurationEntry$fcb698d120847e70;
extern _jc_method _jc_javax_security_auth_login_Configuration$method_info$refresh$23f3d9d8f6b36945;

// Static methods
extern struct _jc_javax_security_auth_login_Configuration$object *_jc_javax_security_auth_login_Configuration$method$getConfig$ae8190efe4619716(_jc_env *);
extern struct _jc_javax_security_auth_login_Configuration$object *_jc_javax_security_auth_login_Configuration$method$getConfiguration$3b919404299eb37d(_jc_env *);
extern void _jc_javax_security_auth_login_Configuration$method$setConfiguration$c053621ad59d4e27(_jc_env *, struct _jc_javax_security_auth_login_Configuration$object *);

// Virtual methods structure
struct _jc_javax_security_auth_login_Configuration$vmethods {
	_jc_object_array	*(*getAppConfigurationEntry$fcb698d120847e70)(_jc_env *, struct _jc_javax_security_auth_login_Configuration$object *, struct _jc_java_lang_String$object *);
	void	(*refresh$23f3d9d8f6b36945)(_jc_env *, struct _jc_javax_security_auth_login_Configuration$object *);
};

// Vtable
struct _jc_javax_security_auth_login_Configuration$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_security_auth_login_Configuration$vmethods	javax_security_auth_login_Configuration;
};

// Vtype
struct _jc_javax_security_auth_login_Configuration$vtype {
	_jc_type			type;
	_jc_javax_security_auth_login_Configuration$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_security_auth_login_Configuration$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_security_auth_login_Configuration$refs {
    _jc_javax_security_auth_login_Configuration$sub_refs	javax_security_auth_login_Configuration;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_security_auth_login_Configuration$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_security_auth_login_Configuration$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_security_auth_login_Configuration$sub_nonrefs	javax_security_auth_login_Configuration;
};

// Object instance structure
struct _jc_javax_security_auth_login_Configuration$object {
	_jc_javax_security_auth_login_Configuration$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_security_auth_login_Configuration$vtype	*vtype;
	_jc_javax_security_auth_login_Configuration$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_security_auth_login_Configuration$vtype _jc_javax_security_auth_login_Configuration$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_security_auth_login_Configuration, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_security_auth_login_Configuration$class_object;

#endif	/* _JC_javax_security_auth_login_Configuration_H_ */

==> jc-1.4.6.tar.gz: javax/security/auth/login/Configuration.h <==
// public abstract class javax.security.auth.login.Configuration

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2ef6b4ae807df814 javax_security_auth_login_Configuration

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_security_auth_login_Configuration_H_
#define _JC_javax_security_auth_login_Configuration_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_security_auth_login_Configuration$object;

// Typedefs
typedef struct _jc_javax_security_auth_login_Configuration$sub_refs	_jc_javax_security_auth_login_Configuration$sub_refs;
typedef struct _jc_javax_security_auth_login_Configuration$sub_nonrefs	_jc_javax_security_auth_login_Configuration$sub_nonrefs;
typedef struct _jc_javax_security_auth_login_Configuration$refs	_jc_javax_security_auth_login_Configuration$refs;
typedef struct _jc_javax_security_auth_login_Configuration$nonrefs	_jc_javax_security_auth_login_Configuration$nonrefs;
typedef struct _jc_javax_security_auth_login_Configuration$object	_jc_javax_security_auth_login_Configuration$object;

typedef struct _jc_javax_security_auth_login_Configuration$fields_struct	_jc_javax_security_auth_login_Configuration$fields_struct;
typedef const struct _jc_javax_security_auth_login_Configuration$vmethods	_jc_javax_security_auth_login_Configuration$vmethods;
typedef const struct _jc_javax_security_auth_login_Configuration$vtable	_jc_javax_security_auth_login_Configuration$vtable;
typedef const struct _jc_javax_security_auth_login_Configuration$vtype	_jc_javax_security_auth_login_Configuration$vtype;

// Class fields structure
struct _jc_javax_security_auth_login_Configuration$fields_struct {
	struct _jc_javax_security_auth_login_Configuration$object	*config;
};
extern _jc_javax_security_auth_login_Configuration$fields_struct _jc_javax_security_auth_login_Configuration$class_fields;

// Constructors
extern void _jc_javax_security_auth_login_Configuration$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_security_auth_login_Configuration$object *) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_object_array *_jc_javax_security_auth_login_Configuration$method$getAppConfigurationEntry$fcb698d120847e70(_jc_env *, struct _jc_javax_security_auth_login_Configuration$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_javax_security_auth_login_Configuration$method$refresh$23f3d9d8f6b36945(_jc_env *, struct _jc_javax_security_auth_login_Configuration$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_security_auth_login_Configuration$method_info$getAppConfigurationEntry$fcb698d120847e70;
extern _jc_method _jc_javax_security_auth_login_Configuration$method_info$refresh$23f3d9d8f6b36945;

// Static methods
extern struct _jc_javax_security_auth_login_Configuration$object *_jc_javax_security_auth_login_Configuration$method$getConfig$ae8190efe4619716(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_javax_security_auth_login_Configuration$object *_jc_javax_security_auth_login_Configuration$method$getConfiguration$3b919404299eb37d(_jc_env *) _JC_JCNI_ATTR;
extern void _jc_javax_security_auth_login_Configuration$method$setConfiguration$c053621ad59d4e27(_jc_env *, struct _jc_javax_security_auth_login_Configuration$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_security_auth_login_Configuration$vmethods {
	_jc_object_array	*(*getAppConfigurationEntry$fcb698d120847e70)(_jc_env *, struct _jc_javax_security_auth_login_Configuration$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	void	(*refresh$23f3d9d8f6b36945)(_jc_env *, struct _jc_javax_security_auth_login_Configuration$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_security_auth_login_Configuration$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_security_auth_login_Configuration$vmethods	javax_security_auth_login_Configuration;
};

// Vtype
struct _jc_javax_security_auth_login_Configuration$vtype {
	_jc_type			type;
	_jc_javax_security_auth_login_Configuration$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_security_auth_login_Configuration$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_security_auth_login_Configuration$refs {
    _jc_javax_security_auth_login_Configuration$sub_refs	javax_security_auth_login_Configuration;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_security_auth_login_Configuration$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_security_auth_login_Configuration$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_security_auth_login_Configuration$sub_nonrefs	javax_security_auth_login_Configuration;
};

// Object instance structure
struct _jc_javax_security_auth_login_Configuration$object {
	_jc_javax_security_auth_login_Configuration$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_security_auth_login_Configuration$vtype	*vtype;
	_jc_javax_security_auth_login_Configuration$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_security_auth_login_Configuration$vtype _jc_javax_security_auth_login_Configuration$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_security_auth_login_Configuration, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_security_auth_login_Configuration$class_object;

#endif	/* _JC_javax_security_auth_login_Configuration_H_ */
